@@ -10,7 +10,7 @@ use Perinci::Object 'envresmulti';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-10-21'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our %SPEC;
 
@@ -31,9 +31,6 @@ $SPEC{google_search} = {
     summary => '(DEPRECATED) Open google search page in browser',
     description => <<'_',
 
-*DEPRECATION NOTICE*: Deprecated in favor of <prog:web-search> from
-<pm:App::WebSearchUtils>.
-
 This utility can save you time when you want to open multiple queries (with
 added common prefix/suffix words) or specify some options like time limit. It
 will formulate the search URL(s) then open them for you in browser. You can also
@@ -428,7 +425,7 @@ sub google_search {
 }
 
 1;
-# ABSTRACT: CLI utilites related to google searching
+# ABSTRACT: (DEPRECATED) CLI utilites related to google searching
 
 __END__
 
@@ -438,11 +435,11 @@ __END__
 
 =head1 NAME
 
-App::GoogleSearchUtils - CLI utilites related to google searching
+App::GoogleSearchUtils - (DEPRECATED) CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.015 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-10-21.
+This document describes version 0.016 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-10-21.
 
 =head1 SYNOPSIS
 
@@ -454,6 +451,11 @@ This distribution provides the following utilities:
 
 =back
 
+=head1 DESCRIPTION
+
+*DEPRECATION NOTICE*: Deprecated in favor of L<App::WebSearchUtils> and
+ L<web-search>.
+
 =head1 FUNCTIONS
 
 
@@ -465,9 +467,6 @@ Usage:
 
 (DEPRECATED) Open google search page in browser.
 
-I<DEPRECATION NOTICE>: Deprecated in favor of L<web-search> from
-L<App::WebSearchUtils>.
-
 This utility can save you time when you want to open multiple queries (with
 added common prefix/suffix words) or specify some options like time limit. It
 will formulate the search URL(s) then open them for you in browser. You can also
